from django.contrib import messages
from django.http import HttpResponseRedirect

from .exceptions import Bounce


class BouncingMiddleware:

    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        return self.get_response(request)

    def process_exception(self, request, exception):
        if isinstance(exception, Bounce):
            if exception.message:
                messages.add_message(
                    request,
                    exception.level,
                    exception.message
                )
            return HttpResponseRedirect(exception.url)



from django.contrib.messages import constants


class Bounce(Exception):

    def __init__(self, url, message=None, level=None, *args):
        """
        :param url: Where you want the user to be bounced to
        :param level: one of the following (we're limited to the values in the
                      messaging framework:
                        * ``DEBUG``
                        * ``INFO``
                        * ``SUCCESS``
                        * ``WARNING``
                        * ``ERROR``
        :param message: The message to send the user, if any.
        :param args: Everything else is passed to ``Exception()``.
        """

        self.url = url
        self.message = message
        self.level = constants.INFO
        if level:
            self.level = getattr(constants, level.upper(), self.level)

        super().__init__("Bouncing user to {}".format(self.url), *args)



import os
import re

from setuptools import setup


def get_version():
    version_file = os.path.join(
        os.path.dirname(__file__),
        'django_tigger',
        '__init__.py'
    )
    with open(version_file) as f:
        regex = re.compile("^__version__.*?\(([\d]+), *([\d]+), *([\d]+)\).*")
        for line in f:
            m = regex.match(line)
            if m:
                return ".".join(m.groups())


# Allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

readme = os.path.join(os.path.dirname(__file__), "README.rst")
github = "https://github.com/danielquinn"
with open(readme) as description:
    setup(
        name="django-tigger",
        version=get_version(),
        license="AGPLv3",
        description="Bounce users out of your view by raising an exception",
        long_description=description.read(),
        url="{}/django-tigger".format(github),
        download_url="{}/django-tigger".format(github),
        author="Daniel Quinn",
        author_email="code@danielquinn.org",
        maintainer="Daniel Quinn",
        maintainer_email="code@danielquinn.org",
        packages=["django_tigger"],
        install_requires=["Django>=1.11"],
        classifiers=[
            "Operating System :: POSIX",
            "Operating System :: Unix",
            "Programming Language :: Python",
            "Programming Language :: Python :: 2.7",
            "Programming Language :: Python :: 3.4",
            "Programming Language :: Python :: 3.5",
            "Programming Language :: Python :: 3.6",
            "Topic :: Internet :: WWW/HTTP",
        ],
    )
